@@ -12,7 +12,7 @@ class HDF5Model(Model):
 
         Model.__init__(self, *args, **kwargs)
 
-        self.search_file(filename)
+        self.search_path(filename)
 
     def read_data(self, *args, **kwargs):
         """This method is automated (see :func:`~pytmosph3r.interface.io.Input.read`).
