@@ -1,22 +1,19 @@
 import os
 import warnings
 import numpy as np
-import ntpath
 from copy import deepcopy
-from functools import wraps
-from logging import Logger
 
 import matplotlib
 import matplotlib.pyplot as plt
 import matplotlib as mpl
 from matplotlib import ticker
 
-from pytmosph3r.plot.loadplot import LoadPlot
+from pytmosph3r.plot.plotutils import *
 from pytmosph3r.emission import Emission
 from pytmosph3r.constants import *
 from pytmosph3r.util.geometry import *
 from pytmosph3r.interface.hdf5 import HDF5Input
-from pytmosph3r.util.util import get_column, get_2D, get_index, get_latitude_index, get_longitude_index
+from pytmosph3r.util.util import get_column, get_2D, get_index, get_latitude_index, get_longitude_index, get_methods, prop
 import exo_k as xk
 
 # some global matplotlib vars
@@ -27,121 +24,6 @@ mpl.rcParams['errorbar.capsize'] = 2
 prop_cycle = plt.rcParams['axes.prop_cycle']
 prop_colors = prop_cycle.by_key()['color']
 
-def clippedcolorbar(CS, **kwargs):
-    from matplotlib.cm import ScalarMappable
-    from numpy import arange, floor, ceil
-    fig = CS.ax.get_figure()
-    vmin = CS.get_clim()[0]
-    vmax = CS.get_clim()[1]
-    m = ScalarMappable(cmap=CS.get_cmap())
-    m.set_array(CS.get_array())
-    m.set_clim(CS.get_clim())
-    step = CS.levels[1] - CS.levels[0]
-    cliplower = CS.zmin<vmin
-    clipupper = CS.zmax>vmax
-    noextend = 'extend' in kwargs.keys() and kwargs['extend']=='neither'
-    # set the colorbar boundaries
-    boundaries = arange((floor(vmin/step)-1+1*(cliplower and noextend))*step, (ceil(vmax/step)+1-1*(clipupper and noextend))*step, step)
-    kwargs['boundaries'] = boundaries
-    # if the z-values are outside the colorbar range, add extend marker(s)
-    # This behavior can be disabled by providing extend='neither' to the function call
-    if not('extend' in kwargs.keys()) or kwargs['extend'] in ['min','max']:
-        extend_min = cliplower or ( 'extend' in kwargs.keys() and kwargs['extend']=='min' )
-        extend_max = clipupper or ( 'extend' in kwargs.keys() and kwargs['extend']=='max' )
-        if extend_min and extend_max:
-            kwargs['extend'] = 'both'
-        elif extend_min:
-            kwargs['extend'] = 'min'
-        elif extend_max:
-            kwargs['extend'] = 'max'
-    return fig.colorbar(m, **kwargs)
-
-def warning(f):
-    """A decorator to try if function failed and issue a warning if it did."""
-    @wraps(f)
-    def wrapper(*args, **kwargs):
-        if BasePlot.debug:
-            return f(*args, **kwargs)
-        try:
-            return f(*args, **kwargs)
-        except Exception as e:
-            warnings.warn("%s() failed with: %s"%(f.__name__, e))
-    return wrapper
-
-def path_leaf(path):
-    head, tail = ntpath.split(path)
-    if (tail == "output_pytmosph3r.h5" or "output_pytmosph3r.h5") and head not in (".", ""):
-        return head # they all have the same name anyway
-    return tail or ntpath.basename(head)
-
-class BasePlot(Logger):
-    x_colors = {'H2O': 'red', 'CO': '#BFFF00','H2': 'black',  'He': 'blue', 'TiO': 'green', 'VO': 'purple',
-                'H': '#ff69b4', 'K': 'cyan', 'CH4': 'cyan', 'NH3': 'magenta', 'N2': '#faebd7',
-                'PH3': '#2e8b57', 'H2S': '#eeefff', 'Fe': '#da70d6', 'FeH': '#ff7f50',
-                'CrH': '#cd853f', 'Na': '#bc8f8f', 'CO2': '#5f9ea0', 'HCN': '#daa520'}
-    debug = False
-
-    def __init__(self, name, *args, **kwargs):
-        """Default values for plots."""
-        self.altitudes = ["surface", "middle", "top"]
-        """Altitudes to plot. Possible values are indices or :attr:`surface`, :attr:`top` or :attr:`middle`."""
-        self.latitudes = ["north", "equator", "south"]
-        """Latitudes to plot. Possible values are indices or :attr:`north`, :attr:`south` or :attr:`equator`. :attr:`north` is latitude :attr:`0`."""
-        self.latitude = "north"
-        self.longitudes = ["day", "terminator", "night"]
-        """Longitudes to plot. Possible values are indices or :attr:`day`, :attr:`night` or :attr:`terminator`. :attr:`night` is longitude :attr:`0`."""
-        self.longitude = "day"
-        super().__init__(name or self.__class__.__name__)
-
-    """Base class for plotting."""
-    def plot_columns(self, func, title="plot", legend=None, figsize=None, *args, **kwargs):
-        """Iterate over vertical columns (lat,lon)."""
-        nrows = len(self.latitudes)
-        ncols = len(self.longitudes)
-        if figsize is None:
-            figsize = (3.2*(ncols+1), 3.2*(nrows))
-        fig, axes = plt.subplots(nrows=nrows, ncols=ncols, sharex=True, sharey=True, figsize=figsize)
-        axes = np.reshape(axes, (nrows, ncols))
-
-        for i, lat in enumerate(self.latitudes):
-            for j, lon in enumerate(self.longitudes):
-                self.latitude = lat
-                self.longitude = lon
-                results = func(ax=axes[i,j], *args, **kwargs)
-
-        ax = fig.add_subplot(111, frame_on=False)
-        plt.tick_params(labelcolor="none", bottom=False, left=False)
-        if legend is not None:
-            legend(axes, fig, results)
-        self.save_plot(title)
-
-    def plot_column(self, ax, x, y, *args, **kwargs):
-        """Plot something at column (lat,lon)."""
-        hx = get_column(x, self.latitude, self.longitude)
-        hy = get_column(y, self.latitude, self.longitude)
-        if isinstance(hx, (float, str)):
-            hx = np.full(hy.shape, hx)
-        elif isinstance(hy, (float, str)):
-            hy = np.full(hx.shape, hy)
-        ax.plot(hx, hy, *args, **kwargs)
-
-    def legend(self):
-        legend = plt.legend(loc='upper left', ncol=1, prop={'size':11})
-        legend.get_frame().set_facecolor('white')
-        legend.get_frame().set_edgecolor('white')
-        legend.get_frame().set_alpha(0.8)
-
-    def save_plot(self, name="plot", suffix=None):
-        if suffix == None:
-            suffix = self.suffix
-        filename = os.path.join(self.out_folder, '%s_%s.pdf' % (name, suffix))
-        plt.savefig(filename)
-        print("Saved %s"%filename)
-        if self.interactive:
-            plt.show()
-        else:
-            plt.close()
-
 class Plot(BasePlot, LoadPlot):
     """Plot one model, either read from a HDF5 file or directly after its computation.
 
@@ -153,7 +35,7 @@ class Plot(BasePlot, LoadPlot):
 
     def __init__(self,pytmosph3r_h5=None,title=None,label=None,
     suffix=None, out_folder='.', cmap='Paired',
-    r_factor=1., h_unit=1e6, zmax=np.inf, pmin=None,
+    r_factor=1., h_unit=1e6, zmax=np.inf, pmin=None, substellar_longitude=None,
     interactive=False, model=None, *args, **kwargs):
         super().__init__(self, self.__class__.__name__, *args, **kwargs)
         self.h_unit = h_unit
@@ -164,8 +46,13 @@ class Plot(BasePlot, LoadPlot):
         """Radius factor (for visual purposes). By default 1."""
         self._p_min = pmin
         """Min (top) pressure to plot."""
+        self.substellar_longitude  = substellar_longitude
+        if substellar_longitude is not None:
+            self.substellar_longitude  = float(substellar_longitude)
+        """Longitude of the substellar point (in degrees)."""
         self.f = None
 
+
         if pytmosph3r_h5:
             if os.path.splitext(pytmosph3r_h5)[-1] != ".h5":
                 try:
@@ -202,6 +89,15 @@ class Plot(BasePlot, LoadPlot):
         self.label=label
         self.p_id = label
 
+    def inputs(self):
+        return ["pytmosph3r_h5","title","label", "suffix", "out_folder" "cmap", "r_factor", "h_unit", "zmax", "pmin", "substellar_longitude", "interactive", "model"]
+
+    def __repr__(self) -> str:
+        msg = "The inputs of "+ self.__class__.__name__ + "() are:\n %s\n"%(self.inputs())
+        msg += "An exhaustive list of methods: \n "
+        msg += "%s"%(get_methods(self))
+        return msg
+
     def get_value_dim(self, index, dim):
         """Returns the value at :attr:`index` in the dimension :attr:`dim`.
 
@@ -212,7 +108,7 @@ class Plot(BasePlot, LoadPlot):
         if isinstance(index, (str,)):
             return index # return text as is
         unit = "°"
-        if dim is "altitude":
+        if dim == "altitude":
             if isinstance(self.radiative_transfer, Emission):
                 unit = 'Pa'
                 array = self.pressure_levels
@@ -223,20 +119,20 @@ class Plot(BasePlot, LoadPlot):
                 elif self.h_unit == 1e3:
                     unit = 'Km'
                 array = self.z
-        elif dim is "latitude":
+        elif dim == "latitude":
             array = np.degrees(self.grid.mid_latitudes)
-        elif dim is "longitude":
+        elif dim == "longitude":
             array = np.degrees(self.grid.mid_longitudes)
         else:
             self.error("I don't know dimension %s"%dim)
             return -1
         return "%.1f %s"%(array[index], unit)
 
-    @property
+    @prop
     def idx_latitude(self):
         return get_latitude_index(self.latitude, self.n_latitudes)
 
-    @property
+    @prop
     def idx_longitude(self):
         return get_longitude_index(self.longitude, self.n_longitudes)
 
@@ -492,9 +388,9 @@ class Plot(BasePlot, LoadPlot):
         ax = self.map_2D(self.temperature, location, dim, ax, *args, **kwargs)
         index = get_index(self.grid,location,dim)
         dim_display = dim
-        if isinstance(self.radiative_transfer, Emission) and dim is "altitude":
+        if isinstance(self.radiative_transfer, Emission) and dim == "altitude":
             dim_display = "pressure"
-        ax.set_title("Temperature (K) @ %s %s"%(dim_display, self.get_value_dim(index, dim)))
+        ax.set_title("Temperature (K) at %s %s"%(dim_display, self.get_value_dim(index, dim)))
         self.save_plot("t_map_%s_%s" % (dim, index))
 
     @warning
@@ -521,9 +417,9 @@ class Plot(BasePlot, LoadPlot):
 
         index = get_index(self.grid,location,dim)
         dim_display = dim
-        if isinstance(self.radiative_transfer, Emission) and dim is "altitude":
+        if isinstance(self.radiative_transfer, Emission) and dim == "altitude":
             dim_display = "pressure"
-        ax.set_title("log([%s]) @ %s %s"%(gas, dim_display, self.get_value_dim(index, dim)))
+        ax.set_title("log([%s]) at %s %s"%(gas, dim_display, self.get_value_dim(index, dim)))
         # self.zp_legend(ax, fig)
         os.makedirs(os.path.join(self.out_folder, gas), exist_ok=True)
         self.save_plot(os.path.join(gas, "x_map"), "%s_%s" % (dim, index))
@@ -553,9 +449,9 @@ class Plot(BasePlot, LoadPlot):
 
         index = get_index(self.grid,location,dim)
         dim_display = dim
-        if isinstance(self.radiative_transfer, Emission) and dim is "altitude":
+        if isinstance(self.radiative_transfer, Emission) and dim == "altitude":
             dim_display = "pressure"
-        ax.set_title("Aerosol MMR: log(%s) @ %s %s"%(aerosol, dim_display, self.get_value_dim(index, dim)))
+        ax.set_title("Aerosol MMR: log(%s) at %s %s"%(aerosol, dim_display, self.get_value_dim(index, dim)))
         # self.zp_legend(ax, fig)
         os.makedirs(os.path.join(self.out_folder, aerosol), exist_ok=True)
         self.save_plot(os.path.join(aerosol, "a_map"), "%s_%s" % (dim, index))
@@ -614,7 +510,7 @@ class Plot(BasePlot, LoadPlot):
         if self.title:
             plt.title(self.title, fontsize=14)
         if save:
-            self.x_legend(ax)
+            self.x_legend(ax, fig)
             self.save_plot(self.savecolumn('mixratio'))
         return gas_legends, min_mix, max_mix
 
@@ -707,14 +603,20 @@ class Plot(BasePlot, LoadPlot):
         self.plot_columns(self.plot_zp, title="zp", legend=self.zp_legend, *args, **kwargs)
 
     @warning
-    def plot_spectrum(self, ax=None, save=False, resolution=None, ylabel=None, dashes=[], linewidth=.5, legend=True, log=False, color=None, *args, **kwargs):
+    def plot_spectrum(self, ax=None, save=False, phase=None, resolution=None, ylabel=None, dashes=[], linewidth=.5, legend=True, log=False, color=None, *args, **kwargs):
+        """Plot a spectrum.
+
+        Args:
+            phase (ndarray, optional): List of phases to plot (in emission mode only). BEWARE: if :attr:`substellar_longitude` has not been set, this should be the observer longitude! Defaults to None.
+            resolution (int, optional): Number of points to bin to. Defaults to None.
+        """
         if ax is None:
             fig, ax = plt.subplots(figsize=(5.3, 3.5))
             save = True
             ax.set_xlabel(r"$\lambda(\mu m)$")
 
         if self.noised_spectrum is not None:
-            noise = xk.Spectrum(np.full_like(self.noised_spectrum.wns, self.model.noise), self.noised_spectrum.wns, self.noised_spectrum.wnedges)
+            noise = xk.Spectrum(np.full_like(self.noised_spectrum.wns, self.noise), self.noised_spectrum.wns, self.noised_spectrum.wnedges)
             if resolution:
                 spectrum = self.bin_down(resolution, self.noised_spectrum)
             else:
@@ -722,13 +624,30 @@ class Plot(BasePlot, LoadPlot):
                 below = spectrum.value-noise.value
                 above = spectrum.value+noise.value
                 ax.fill_between(spectrum.wls, below, above, alpha=0.4, zorder=-2, edgecolor='none', color=color)
-            ax.plot(spectrum.wls, spectrum.value, dashes=dashes, label=self.label, linewidth=linewidth, color=color, *args, **kwargs)
         else:
             spectrum = self.spectrum
             if resolution:
                 spectrum = self.bin_down(resolution, copy=True)
 
-            ax.plot(spectrum.wls, spectrum.value, dashes=dashes, label=self.label, linewidth=linewidth, *args, **kwargs)
+        if isinstance(phase, bool) or phase is None:
+            ax.plot(spectrum.wls, spectrum.value, dashes=dashes, label=self.label, linewidth=linewidth, color=color, *args, **kwargs)
+        else:
+            try:
+                flux = self.radiative_transfer.phase_curve
+            except:
+                self.warning("No phase curve to plot. If you want it, set 'phase_curve' to True.")
+                return
+            longitudes = np.degrees(self.radiative_transfer.observer_longitudes)
+            label = "$\lambda_{obs}$"
+            if self.substellar_longitude is not None:
+                flux = flux[::-1]
+                longitudes = np.degrees(np.pi+np.radians(self.substellar_longitude)-self.radiative_transfer.observer_longitudes)[::-1] # reversed for searching
+                label = "$\phi$"
+            if isinstance(phase, (float,int)):
+                phase = [phase]
+            for ph in phase:
+                ph_index = longitudes.searchsorted(float(ph), 'left')
+                ax.plot(spectrum.wls, flux[ph_index], label=r"%s = %.1f°"%(label, longitudes[ph_index]), *args, **kwargs)
 
         ax.set_xscale('log')
         if log:
@@ -751,22 +670,22 @@ class Plot(BasePlot, LoadPlot):
             self.save_plot("spectrum")
 
     @warning
-    def transmittance_map(self, wl=.6, ax=None, title="Transmittance @ ", cmap="gnuplot", overlay=True, *args, **kwargs):
+    def transmittance_map(self, wl=.6, ax=None, title="Transmittance at ", cmap="gnuplot", overlay=True, *args, **kwargs):
         """Plot transmittance at a specific wavelength :attr:`wl` (or closest inferior wavelength).
         """
         if hasattr(wl, '__len__'):
             if len(wl) > 1:
                 fig = plt.figure()#figsize=(5,3.5))
                 # iterate over wavelengths
-                nrows = int((len(wl)+1)/2)
-                ncols = int((len(wl)+1)/nrows)
+                ncols = int((len(wl)+1)/2)
+                nrows = int((len(wl)+1)/ncols)
                 axes = []
                 for i, wavelength in enumerate(wl):
                     ax = fig.add_subplot(nrows, ncols, i+1, polar=True)
                     axes.append(ax)
                     cs = self.transmittance_map(wl=float(wavelength), ax=ax, title="", cmap=cmap, *args, **kwargs)
                 fig.subplots_adjust(right=1)
-                fig.colorbar(cs, ticks=ticker.LinearLocator(11), format='%.1f', ax=axes)
+                clippedcolorbar(cs, format='%.3f', ax=axes)
                 self.save_plot("transmittance")
                 return
             wl = wl[0]
@@ -840,7 +759,7 @@ class Plot(BasePlot, LoadPlot):
         return cs
 
     @warning
-    def emission_map(self, wl=15., ax=None, title="Emission @ ", cmap="gnuplot", overlay=True, figsize=(5,3.5), *args, **kwargs):
+    def emission_map(self, wl=15., ax=None, title="Emission at ", cmap="gnuplot", overlay=True, figsize=(5,3.5), *args, **kwargs):
         """Plot emission at a specific wavelength :attr:`wl` (or closest inferior wavelength, in micrometer).
         """
         if hasattr(wl, '__len__'):
@@ -901,7 +820,7 @@ class Plot(BasePlot, LoadPlot):
         return cs
 
     @warning
-    def plot_phase_curve(self, wl=15, ax=None, title="Phase curve @ ", legend=True, figsize=(5,3.5), *args, **kwargs):
+    def plot_phase_curve(self, wl=15, ax=None, legend=True, figsize=(5,3.5), *args, **kwargs):
         save = False
         if ax is None:
             save = True
@@ -912,17 +831,25 @@ class Plot(BasePlot, LoadPlot):
         if isinstance(wl, (float,int)):
             wl = [wl]
 
+        try:
+            x = np.degrees(self.radiative_transfer.observer_longitudes)
+        except:
+            self.warning("No phase curve to plot. If you want it, set 'phase_curve' to True.")
+            return
+        if self.substellar_longitude is not None:
+            x = np.degrees(np.pi+np.radians(self.substellar_longitude)-self.radiative_transfer.observer_longitudes)
+
         for w in wl:
             wl_index = len(wls) - wls.searchsorted(float(w), 'right')
             wl_index = min(len(wls)-1, wl_index) # outside of bounds
-            try:
-                flux = self.radiative_transfer.phase_curve[..., wl_index]
-            except:
-                self.warning("No phase curve to plot. If you want it, set 'phase_curve' to True.")
-                return
-            ax.plot(np.degrees(self.radiative_transfer.phase_longitudes), flux, label=r"%.3f $\mu m$"%self.spectrum.wls[wl_index])
+            flux = self.radiative_transfer.phase_curve[..., wl_index]
+            if self.substellar_longitude is not None:
+                flux = flux[::-1]
+            ax.plot(x, flux, label=r"%.3f $\mu m$"%self.spectrum.wls[wl_index], *args, **kwargs)
 
-        ax.set_xlabel('Phase angle (degrees)')
+        ax.set_xlabel('Observer longitude (degrees)')
+        if self.substellar_longitude is not None:
+            ax.set_xlabel('Phase angle (degrees)')
         ylabel = "Flux $(W/m^2/cm^{-1})$"
         if self.radiative_transfer.planet_to_star_flux_ratio:
             ylabel = "$F_P/F_S$"
@@ -934,6 +861,50 @@ class Plot(BasePlot, LoadPlot):
         if save:
             self.save_plot("phase_curve")
 
+    @warning
+    def plot_phase_curves(self, ax=None, title=None, figsize=(5,3.5), cmap="gnuplot", *args, **kwargs):
+        """2D phase curves (imshow). If you want the X-axis to be in phases, you have to specify the longitude of the substellar point.
+
+        Args:
+            substellar_longitude (float, optional): Longitude (in degrees) of the substellar point. If set, the X-axis of the plot will be in phases. Defaults to None.
+            figsize (tuple, optional): Size of the figure. Defaults to (5,3.5).
+            cmap (str, optional): Colormap to use in the imshow(). Defaults to "gnuplot".
+        """
+        save = False
+        if ax is None:
+            save = True
+            fig = plt.figure(figsize=figsize)
+            ax = fig.add_subplot(111)
+
+        try:
+            flux = self.radiative_transfer.phase_curve
+        except:
+            self.warning("No phase curve to plot. If you want it, set 'phase_curve' to True.")
+            return
+        x = self.spectrum.wls
+        y = np.degrees(self.radiative_transfer.observer_longitudes)
+        if self.substellar_longitude is not None:
+            y = np.degrees(np.pi+np.radians(self.substellar_longitude)-self.radiative_transfer.observer_longitudes)
+            flux = flux[::-1]
+        if x[0] > x[-1]:
+            flux = flux[..., ::-1] # get increasing spectral axis for imshow
+        cs = ax.imshow(flux, extent=[x.min(), x.max(), y.min(), y.max()], aspect='auto', cmap=cmap, *args, **kwargs)
+
+        ax.set_xlabel(r"$\lambda(\mu m)$")
+        ax.set_ylabel('Observer longitude (degrees)')
+        if self.substellar_longitude is not None:
+            ax.set_ylabel('Phase angle (degrees)')
+        if title is None:
+            title = "Flux $(W/m^2/cm^{-1})$"
+            if self.radiative_transfer.planet_to_star_flux_ratio:
+                title = "$F_P/F_S$"
+        ax.set_title(title)
+
+        plt.tight_layout(pad=1)
+        if save:
+            fig.colorbar(cs)
+            self.save_plot("phase_curves")
+
 class Comparison(Plot):
     """Compare (and plot) multiple models."""
     def __init__(self, models=None,title=None,suffix=None,cmap='Paired',out_folder='.', interactive=False):
@@ -979,7 +950,7 @@ class Comparison(Plot):
         if save:
             self.save_plot("spectra")
 
-    def diff_spectra(self, title="Difference", ids=None, colors=None, ax=None, log=False, abs=True, resolution=None, figsize=(4,4), legend=True, ylabel="\Delta $(R_p/R_s)^2$", *args, **kwargs):
+    def diff_spectra(self, title="Difference", ids=None, colors=None, ax=None, log=False, abs=True, resolution=None, figsize=(4,4), legend=True, ylabel=r"$\Delta (R_p/R_s)^2$", *args, **kwargs):
         """
         Compare models using ids. Example of use: comparison.diff_spectra(ids=[["3D", "1D"],["3D", "1D"]])
         """
@@ -1135,7 +1106,7 @@ class Comparison(Plot):
         """All comparison plots. longitude = 1 plots the terminator"""
         fig, ax = plt.subplots(nrows=2, ncols=1, figsize=(4,5.5), gridspec_kw={'height_ratios': [3, 1]})
         self.plot_spectra(ids=plots, ax=ax[0], ylabel=ylabel, *args, **kwargs)
-        self.diff_spectra(ids=compares, ax=ax[1], ylabel='\Delta '+ylabel, legend=False, *args, **kwargs)
+        self.diff_spectra(ids=compares, ax=ax[1], ylabel=r'$\Delta $'+ylabel, legend=False, *args, **kwargs)
         self.save_plot("spectra_diff"+suffix)
 
     @warning
@@ -1159,9 +1130,10 @@ def main():
     parser.add_argument("-t","--plot-tpprofile",dest="tpprofile",default=False,help="Plot Temperature profiles",action='store_true')
     parser.add_argument("-z","--plot-zpprofile",dest="zpprofile",default=False,help="Plot Altitude-Pressure profiles",action='store_true')
     parser.add_argument("-d","--plot-tau",dest="tau",default=False,help="Plot optical depth contribution",action="store_true")
-    parser.add_argument("-s","--plot-spectrum",dest="spectrum",default=False,help="Plot spectrum",action='store_true')
+    parser.add_argument("-s","--plot-spectrum",dest="spectrum",nargs='*',default=False, help="Plot spectrum")
     parser.add_argument("-tr","--transmittance",dest="transmittance",nargs='*',default=False, help="Plot transmittance")
     parser.add_argument("-e","--emission",dest="emission",nargs='*',default=False, help="Plot emission")
+    parser.add_argument("-sl","--substellar-longitude",dest="substellar_longitude", default=None, type=float, help="Define longitude of the substellar point.")
     parser.add_argument("-2D","--plot-2D",dest="plot_2D",default=False,help="Plot all 2D profiles (T, P, gases, aerosols)",action="store_true")
     parser.add_argument("-g", "--debug", dest='debug',default=False,action="store_true", help="Force to stop on fail.")
     parser.add_argument("-int","--interactive",dest="interactive",default=False,help="Interactive plot",action='store_true')
@@ -1192,12 +1164,11 @@ def main():
     plot_aprofile = args.aprofile or args.all
     plot_tp_profile = args.tpprofile or args.all
     plot_zp_profile = args.zpprofile or args.all
-    plot_spectrum = args.spectrum or args.all
+    plot_spectrum = args.spectrum or (not isinstance(args.spectrum, bool) and not len(args.spectrum)) or args.all
     transmittance = args.transmittance or (not isinstance(args.transmittance, bool) and not len(args.transmittance)) or args.all
     emission = args.emission or (not isinstance(args.emission, bool) and not len(args.emission)) or args.all
-    plot_2D = args.plot_2D or args.all
     plot_rays = args.plot_rays or (args.all == 2) or args.mid_points
-    if not (plot_xprofile or plot_tp_profile or plot_zp_profile or plot_spectrum or transmittance or plot_2D or plot_rays):
+    if not (plot_xprofile or plot_tp_profile or plot_zp_profile or plot_spectrum or transmittance or args.plot_2D or plot_rays):
         plot_spectrum = True # if no plot, then plot spectrum
 
     print("Plotting %s"%args.input_files)
@@ -1214,7 +1185,9 @@ def main():
                         title=args.title,suffix=args.suffix,
                         out_folder=args.output_dir,
                         zmax=args.zmax,
-                        r_factor=args.r_factor, label=labels[idx])
+                        r_factor=args.r_factor,
+                        substellar_longitude=args.substellar_longitude,
+                        label=labels[idx])
             plot.altitudes = args.altitudes
             plot.longitudes = args.longitudes
             plot.latitudes = args.latitudes
@@ -1247,18 +1220,16 @@ def main():
                     title=args.title,suffix=args.suffix,
                     out_folder=args.output_dir,
                     zmax=args.zmax,
-                    r_factor=args.r_factor)
+                    r_factor=args.r_factor,
+                    substellar_longitude=args.substellar_longitude,
+                    )
 
     plot.altitudes = args.altitudes
     plot.longitudes = args.longitudes
     plot.latitudes = args.latitudes
 
-    if plot_xprofile:
-        plot.plot_xprofiles()
-    if plot_tp_profile:
-        plot.plot_tps()
-    if plot_zp_profile:
-        plot.plot_zps()
+    if plot_spectrum:
+        plot.plot_spectrum(resolution=args.resolution, phase=plot_spectrum)
     if transmittance:
         if isinstance(transmittance, (bool,)) or len(transmittance) == 0:
             transmittance = 1
@@ -1268,18 +1239,26 @@ def main():
             emission = 1
         plot.emission_map(wl=emission)
         plot.plot_phase_curve(wl=emission)
-    if plot_spectrum:
-        plot.plot_spectrum(resolution=args.resolution)
-    if plot_2D or plot_tp_profile:
+        plot.plot_phase_curves()
+    if plot_xprofile:
+        plot.plot_xprofiles()
+    if plot_tp_profile:
+        plot.plot_tps()
+    if plot_zp_profile:
+        plot.plot_zps()
+    if args.plot_2D or plot_tp_profile or args.all:
         plot.t_maps()
+    if args.plot_2D or plot_tp_profile or (args.all>1):
         plot.t_maps(dim="longitude")
         plot.t_maps(dim="altitude")
-    if plot_2D or plot_xprofile:
+    if args.plot_2D or plot_xprofile or args.all:
         plot.x_maps()
+    if args.plot_2D or plot_xprofile or (args.all>1):
         plot.x_maps(dim="longitude")
         plot.x_maps(dim="altitude")
-    if plot_2D or plot_aprofile:
+    if args.plot_2D or plot_aprofile or args.all:
         plot.a_maps()
+    if args.plot_2D or plot_aprofile or (args.all>1):
         plot.a_maps(dim="longitude")
         plot.a_maps(dim="altitude")
     if plot_rays:
