@@ -7,12 +7,12 @@ from pytmosph3r.log import Logger
 from pytmosph3r.rays import Rays
 from pytmosph3r.atmosphere import AltitudeAtmosphere
 from pytmosph3r.util.memory import *
-from pytmosph3r.util.util import get, make_array, timer, spectral_chunks
-from pytmosph3r.constants import KBOLTZ, RGP
+from pytmosph3r.util.util import make_array, timer, spectral_chunks, prop
+from pytmosph3r.constants import KBOLTZ
 
 @numba.njit
 def compute_optical_depth_mie(P, T, rays_lengths, cross_section, mie_abs_coeff,  opacity_indices, rays_list, n_rays, n_intersection, tau):
-    """Compute tau, the optical depth."""
+    """Computes tau, the optical depth."""
     for r in range(n_rays):
         ray = rays_list[r]
         ray_coords = ray
@@ -29,7 +29,7 @@ def compute_optical_depth_mie(P, T, rays_lengths, cross_section, mie_abs_coeff,
 
 @numba.njit
 def compute_optical_depth(P, T, rays_lengths, cross_section,  opacity_indices, rays_list, n_rays, n_intersection, tau):
-    """Compute tau, the optical depth."""
+    """Computes tau, the optical depth."""
     for r in range(n_rays):
         ray = rays_list[r]
         ray_coords = ray
@@ -43,7 +43,7 @@ def compute_optical_depth(P, T, rays_lengths, cross_section,  opacity_indices, r
                          * cross_section[opacity_indices[coord]])
 
 class Transmission(Logger):
-    """The transmission module compute the transit depth given a set of :attr:`rays` crossing the atmosphere.
+    """The transmission module computes the transit depth :math:`(R_P/R_S)^2` given a set of :attr:`rays` crossing the atmosphere.
 
     Args:
         rays (:class:`~pytmosph3r.rays.Rays` or dict) : Defining the grid (`n_radial`, `n_angular`) of light rays that cross the atmosphere.
@@ -62,7 +62,7 @@ class Transmission(Logger):
         if self.store_transmittance:
             self.transmittance = []
         self.identical = identical
-        """Compute only once opacity for cells with same physical properties (True by default). You can use this to your advantage when an atmosphere has multiple cells with the same properties. If your atmosphere is completely heterogeneous however, consider removing this option (searching for identical cells is a waste of time)."""
+        """Computes only once the opacity for cells with identical physical properties (True by default). You can use this to your advantage when an atmosphere has multiple cells with the same properties. If your atmosphere is completely heterogeneous however, consider removing this option (searching for identical cells is a waste of time)."""
         self.memory_aware = memory_aware
         """Divide the computation of opacities to fit into memory."""
         self.per_angle = per_angle
@@ -109,23 +109,23 @@ class Transmission(Logger):
         self.rays.set_observer(model.observer)
         self.rays.build(model)
 
-    @property
+    @prop
     def opacity(self):
         return self.model.opacity
-    @property
+    @prop
     def atmosphere(self):
         return self.model.atmosphere
 
     @timer
     def prepare_opacities(self, *args, **kwargs):
-        """Prepare opacities list that need to be computed by exo_k.
+        """Prepares opacities list that need to be computed by exo_k.
         Cells with the same physical properties are grouped together to compute their opacity only once.
         Timed function. Use :func:`_prepare_opacities` if time is not needed.
         """
         return self._prepare_opacities(*args, **kwargs)
 
     def _prepare_opacities(self, opacity_coords):
-        """Prepare opacities list that need to be computed by exo_k.
+        """Prepares opacities list that need to be computed by exo_k.
         Cells with the same physical properties are grouped together to compute their opacity only once.
         """
         self.opacity_indices = np.full(self.atmosphere.shape, np.nan, dtype='i')
@@ -177,13 +177,13 @@ class Transmission(Logger):
 
     @timer
     def compute_integral(self, *args, **kwargs):
-        """Compute integral by iterating over opacities given by :func:`prepate_opacities` and if :attr:`memory_aware`, use :func:`wn_chunks` to subdivide the work along the spectral axis.
+        """Computes integral by iterating over opacities given by :func:`prepate_opacities` and if :attr:`memory_aware`, use :func:`wn_chunks` to subdivide the work along the spectral axis.
          Timed function. Use :func:`compute_contribution` if time is not needed.
         """
         return self.compute_contribution(*args, **kwargs)
 
     def compute_contribution(self, opacities):
-        """Compute integral by iterating over opacities given by :func:`prepate_opacities` and if :attr:`memory_aware`, use :func:`wn_chunks` to subdivide the work along the spectral axis.
+        """Computes integral by iterating over opacities given by :func:`prepate_opacities` and if :attr:`memory_aware`, use :func:`wn_chunks` to subdivide the work along the spectral axis.
         """
         indices = opacities[0]
         aer_reff_densities = opacities[1]
@@ -222,7 +222,7 @@ class Transmission(Logger):
 
 
     def wn_chunks(self, xsec_size):
-        """Subdivide the work along the spectral axis.
+        """Subdivides the work along the spectral axis.
         Useful when cross sections + transmittance are too large to fit into memory.
 
         Args:
@@ -285,7 +285,7 @@ class Transmission(Logger):
         return np.sum((1. - transmittance) * S, axis=tuple(range(transmittance.ndim - 1)))
 
     def compute_optical_depth(self):
-        """Compute tau, the optical depth."""
+        """Computes tau, the optical depth."""
         # self.info("Optical depth...")
         tau = np.zeros(self.shape+self.cross_section.shape[1:])
         rays_it = self.rays.walk(self.dim)
@@ -333,7 +333,7 @@ class Transmission(Logger):
         return integral_angle
 
     def grid_to_transmittance(self, bounds=None):
-        """Compute transmittance for rays between bounds.
+        """Computes transmittance for rays between bounds.
 
         Args:
             bounds (tuple): Must be ((r_s,r_e), (a_s,a_e)), where r_s and r_e are the radial start and end points, and a_s and a_e the angular ones.
@@ -350,7 +350,11 @@ class Transmission(Logger):
         return transmittance
 
     def compute(self, model):
-        """Sum all optical depths and compute transit depth (ratio of visible radius of the planet on the radius of the star to the square)."""
+        """Sums all optical depths and computes the transit depth (ratio of visible radius of the planet on the radius of the star to the square :math:`(R_P/R_S)^2`).
+
+        Returns:
+            Spectrum (exo_k object): Spectrum :math:`(R_P/R_S)^2`
+        """
         self.debug("Real Memory before transit depth = %s"% memory_usage())
         self.debug("Virt Memory before transit depth = %s"% memory_usage("VmH"))
         if model.parallel:
